==> 0.0.6-prerelease.tar.gz: lib/src/core/helpers/links_helper.dart <==
part of modern_form_core;

class ModernFormLinksHelper {
  static Future<void> makePhoneCall(String number) async {
    if (kIsWeb) {
      Clipboard.setData(ClipboardData(text: number));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      String url = 'tel:$number';
      if (await canLaunch(url)) {
        await launch(url);
      }
    }
  }

  static Future<void> makeSendMail(String mail) async {
    if (kIsWeb) {
      Clipboard.setData(ClipboardData(text: mail));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      String url = 'mailto:$mail';
      if (await canLaunch(url)) {
        await launch(url);
      }
    }
  }

  static Future<void> shareText(String text) async {
    if (kIsWeb) {
      await Clipboard.setData(ClipboardData(text: text));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      Share.text(
        'Schemaq',
        text ?? "",
        'text/txt',
      );
    }
  }

  static Future<void> showShareType(
    BuildContext context, {
    Future<void> Function() onShareUrl,
    Future<void> Function() onShareArquive,
    Future<void> Function() onDownload,
    menu.ModernFormPopupMenuLocation menuLocation,
  }) async {
    List<ModernFormBottomSheetModel<int>> list = [
      ModernFormBottomSheetModel<int>(text: "Compartilhar URL", value: 0)
    ];
    if (!kIsWeb) {
      list.add(ModernFormBottomSheetModel<int>(
          text: "Compartilhar Arquivo", value: 1));

      if (onDownload != null) {
        list.add(ModernFormBottomSheetModel<int>(
            text: "Fazer download do arquivo", value: 2));
      }
    }
    int response = await showModernFormFilterPopupMenu<int>(
      context,
      forceMenu: true,
      menuLocation: menuLocation,
      list: list,
    );

    if (response != null) {
      switch (response) {
        case 2:
          if (onDownload != null) {
            await onDownload();
          }
          break;
        case 0:
          if (onShareUrl != null) {
            await onShareUrl();
          }
          break;
        case 1:
          if (onShareArquive != null) {
            await onShareArquive();
          }
          break;
        default:
          break;
      }
    }
  }
}

==> 0.1.19-prerelease.tar.gz: lib/src/core/helpers/links_helper.dart <==
part of modern_form_core;

class ModernFormLinksHelper {
  static Future<void> makePhoneCall(String number) async {
    if (kIsWeb) {
      Clipboard.setData(ClipboardData(text: number));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      String url = 'tel:$number';
      if (await canLaunch(url)) {
        await launch(url);
      }
    }
  }

  static Future<void> makeSendMail(String mail) async {
    if (kIsWeb) {
      Clipboard.setData(ClipboardData(text: mail));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      String url = 'mailto:$mail';
      if (await canLaunch(url)) {
        await launch(url);
      }
    }
  }

  static Future<void> shareText(String text) async {
    if (kIsWeb) {
      await Clipboard.setData(ClipboardData(text: text));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      Share.text(
        'Schemaq',
        text ?? "",
        'text/txt',
      );
    }
  }

  static Future<void> showShareType(
    BuildContext context, {
    Future<void> Function() onShareUrl,
    Future<void> Function() onShareArquive,
    Future<void> Function() onDelete,
    menu.ModernFormPopupMenuLocation menuLocation,
  }) async {
    List<ModernFormBottomSheetModel<int>> list = [
      ModernFormBottomSheetModel<int>(text: "Compartilhar URL", value: 0)
    ];
    if (!kIsWeb) {
      list.add(ModernFormBottomSheetModel<int>(
          text: "Compartilhar Arquivo", value: 1));
      if (onDelete != null && !kIsWeb) {
        list.add(ModernFormBottomSheetModel<int>(
            text: "Deletar arquivo do dispositivo", value: 2));
      }
    }
    int response = await showModernFormFilterPopupMenu<int>(
      context,
      forceMenu: true,
      menuLocation: menuLocation,
      list: list,
    );

    if (response != null) {
      switch (response) {
        case 0:
          if (onShareUrl != null) {
            await onShareUrl();
          }
          break;
        case 1:
          if (onShareArquive != null) {
            await onShareArquive();
          }
          break;
        case 2:
          if (onDelete != null) {
            await onDelete();
          }
          break;
        default:
          break;
      }
    }
  }
}
